@@ -366,6 +366,17 @@ void est_mtdb_set_cache_size(ESTMTDB *db, size_t size, int anum, int tnum, int r
 }
 
 
+/* Add a pseudo index directory to a database. */
+int est_mtdb_add_pseudo_index(ESTMTDB *db, const char *path){
+  int rv;
+  assert(db && path);
+  if(!est_mtdb_lock(db)) return FALSE;
+  rv = est_db_add_pseudo_index(db->db, path);
+  est_mtdb_unlock(db);
+  return rv;
+}
+
+
 
 /*************************************************************************************************
  * features for experts
