@@ -133,6 +133,10 @@ int est_mtdb_scan_doc(ESTMTDB *db, ESTDOC *doc, ESTCOND *cond);
 void est_mtdb_set_cache_size(ESTMTDB *db, size_t size, int anum, int tnum, int rnum);
 
 
+/* Add a pseudo index directory to a database. */
+int est_mtdb_add_pseudo_index(ESTMTDB *db, const char *path);
+
+
 
 /*************************************************************************************************
  * features for experts
