@@ -408,15 +408,15 @@ int est_node_sync(ESTNODE *node){
   CBDATUM *reqbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node);
   err = FALSE;
   sprintf(url, "%s/sync", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -445,15 +445,15 @@ int est_node_optimize(ESTNODE *node){
   CBDATUM *reqbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node);
   err = FALSE;
   sprintf(url, "%s/optimize", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -481,15 +481,15 @@ int est_node_put_doc(ESTNODE *node, ESTDOC *doc){
   CBLIST *reqheads;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf, *reqbody;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && doc);
   err = FALSE;
   sprintf(url, "%s/put_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -517,15 +517,15 @@ int est_node_out_doc(ESTNODE *node, int id){
   CBDATUM *reqbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && id > 0);
   err = FALSE;
   sprintf(url, "%s/out_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -555,15 +555,15 @@ int est_node_out_doc_by_uri(ESTNODE *node, const char *uri){
   CBDATUM *reqbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && uri);
   err = FALSE;
   sprintf(url, "%s/out_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -600,8 +600,8 @@ int est_node_edit_doc(ESTNODE *node, ESTDOC *doc){
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -641,15 +641,15 @@ ESTDOC *est_node_get_doc(ESTNODE *node, int id){
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && id > 0);
   err = FALSE;
   sprintf(url, "%s/get_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -683,15 +683,15 @@ ESTDOC *est_node_get_doc_by_uri(ESTNODE *node, const char *uri){
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && uri);
   err = FALSE;
   sprintf(url, "%s/get_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -724,15 +724,15 @@ char *est_node_get_doc_attr(ESTNODE *node, int id, const char *name){
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && id > 0 && name);
   err = FALSE;
   sprintf(url, "%s/get_doc_attr", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -770,15 +770,15 @@ char *est_node_get_doc_attr_by_uri(ESTNODE *node, const char *uri, const char *n
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && uri && name);
   err = FALSE;
   sprintf(url, "%s/get_doc_attr", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -818,15 +818,15 @@ CBMAP *est_node_etch_doc(ESTNODE *node, int id){
   CBLIST *lines;
   const char *kbuf, *pv;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int i, rescode, err, ksiz;
+  int i, rescode, err;
   assert(node && id > 0);
   err = FALSE;
   sprintf(url, "%s/etch_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -872,15 +872,15 @@ CBMAP *est_node_etch_doc_by_uri(ESTNODE *node, const char *uri){
   CBLIST *lines;
   const char *kbuf, *pv;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int i, rescode, err, ksiz;
+  int i, rescode, err;
   assert(node && uri);
   err = FALSE;
   sprintf(url, "%s/etch_doc", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -925,15 +925,15 @@ int est_node_uri_to_id(ESTNODE *node, const char *uri){
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz, id;
+  int rescode, err, id;
   assert(node && uri);
   err = FALSE;
   sprintf(url, "%s/uri_to_id", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -1011,7 +1011,7 @@ double est_node_cache_usage(ESTNODE *node){
   CBDATUM *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   double ratio;
   assert(node);
   err = FALSE;
@@ -1019,8 +1019,8 @@ double est_node_cache_usage(ESTNODE *node){
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -1078,15 +1078,15 @@ ESTNODERES *est_node_search(ESTNODE *node, ESTCOND *cond, int depth){
   CBDATUM *reqbody, *resbody;
   const char *kbuf, *phrase, *order, *cbuf;
   char buf[ESTPATHBUFSIZ], *vbuf, *ptr, *pv, *ep;
-  int i, rescode, err, ksiz, max, plen, part, end;
+  int i, rescode, err, max, plen, part, end;
   assert(node && cond && depth >= 0);
   err = FALSE;
   sprintf(buf, "%s/search", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -1208,15 +1208,15 @@ int est_node_set_user(ESTNODE *node, const char *name, int mode){
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && name);
   err = FALSE;
   sprintf(url, "%s/_set_user", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -1248,15 +1248,15 @@ int est_node_set_link(ESTNODE *node, const char *url, const char *label, int cre
   CBDATUM *reqbody, *resbody;
   const char *kbuf;
   char myurl[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz;
+  int rescode, err;
   assert(node && url && label);
   err = FALSE;
   sprintf(myurl, "%s/_set_link", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -2033,15 +2033,15 @@ static int est_node_set_info(ESTNODE *node){
   CBDATUM *resbody;
   const char *kbuf, *ptr, *pv, *tv;
   char url[ESTPATHBUFSIZ], *vbuf;
-  int rescode, err, ksiz, tc;
+  int rescode, err, tc;
   assert(node);
   err = FALSE;
   sprintf(url, "%s/inform", node->url);
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
@@ -2178,8 +2178,8 @@ static int est_node_read_list(ESTNODE *node){
   reqheads = cblistopen();
   if(cbmaprnum(node->heads) > 0){
     cbmapiterinit(node->heads);
-    while((kbuf = cbmapiternext(node->heads, &ksiz)) != NULL){
-      vbuf = cbsprintf("%s: %s", kbuf, cbmapget(node->heads, kbuf, ksiz, NULL));
+    while((kbuf = cbmapiternext(node->heads, NULL)) != NULL){
+      vbuf = cbsprintf("%s: %s", kbuf, cbmapiterval(kbuf, NULL));
       cblistpush(reqheads, vbuf, -1);
       free(vbuf);
     }
