@@ -205,6 +205,7 @@ char *est_doc_make_snippet(ESTDOC *doc, const CBLIST *words, int wwidth, int hwi
 #define ESTOPID        "[ID]"            /* ID matching search */
 #define ESTOPURI       "[URI]"           /* URI matching search */
 #define ESTOPSIMILAR   "[SIMILAR]"       /* similarity search */
+#define ESTOPRANK      "[RANK]"          /* ranking search */
 
 #define ESTOPUNION     "OR"              /* union (conjunction) */
 #define ESTOPISECT     "AND"             /* intersection (disjunction) */
@@ -231,10 +232,10 @@ char *est_doc_make_snippet(ESTDOC *doc, const CBLIST *words, int wwidth, int hwi
 #define ESTOPNUMLE     "NUMLE"           /* number or date is less than or equal to */
 #define ESTOPNUMBT     "NUMBT"           /* number or date is between two tokens of */
 
-#define ESTORDIDA     "[IDA]"            /* ID numbers in ascending order */
-#define ESTORDIDD     "[IDD]"            /* ID numbers in descending order */
-#define ESTORDSCA     "[SCA]"            /* scores in ascending order */
-#define ESTORDSCD     "[SCD]"            /* scores in descending order */
+#define ESTORDIDA      "[IDA]"           /* ID numbers in ascending order */
+#define ESTORDIDD      "[IDD]"           /* ID numbers in descending order */
+#define ESTORDSCA      "[SCA]"           /* scores in ascending order */
+#define ESTORDSCD      "[SCD]"           /* scores in descending order */
 #define ESTORDSTRA     "STRA"            /* strings in ascending order */
 #define ESTORDSTRD     "STRD"            /* strings in descending order */
 #define ESTORDNUMA     "NUMA"            /* numbers in ascending order */
@@ -249,7 +250,7 @@ typedef struct {                         /* type of structure for search conditi
   char *phrase;                          /* search phrase */
   int gstep;                             /* step of N-gram */
   int tfidf;                             /* whether with TF-IDF tuning */
-  int simple;                            /* whether with the simplified phrase */
+  int pmode;                             /* mode of phrase form */
   void (*cbxpn)(const char *, CBLIST *); /* callback function for query expansion */
   CBLIST *attrs;                         /* conditions with attributes */
   char *order;                           /* sorting order */
@@ -273,6 +274,9 @@ enum {                                   /* enumeration for options */
   ESTCONDAGITO = 1 << 3,                 /* check N-gram keys skipping by three */
   ESTCONDNOIDF = 1 << 4,                 /* without TF-IDF tuning */
   ESTCONDSIMPLE = 1 << 10,               /* with the simplified phrase */
+  ESTCONDROUGH = 1 << 11,                /* with the rough phrase */
+  ESTCONDUNION = 1 << 15,                /* with the union phrase */
+  ESTCONDISECT = 1 << 16,                /* with the intersection phrase */
   ESTCONDSCFB = 1 << 30                  /* feed back scores (for debug) */
 };
 
@@ -323,11 +327,11 @@ void est_cond_set_skip(ESTCOND *cond, int skip);
    `options' specifies options: `ESTCONDSURE' specifies that it checks every N-gram key,
    `ESTCONDUSUAL', which is the default, specifies that it checks N-gram keys with skipping one
    key, `ESTCONDFAST' skips two keys, `ESTCONDAGITO' skips three keys, `ESTCONDNOIDF' specifies
-   not to perform TF-IDF tuning, `ESTCONDSIMPLE' specifies to use simplified phrase, `ESTCONDETCH'
-   specifies to attach the keyword vector (only for the node API), `ESTCONDSCFB' specifies to
-   feed back scores (only for debugging).  Each option can be specified at the same time by
-   bitwise or.  If keys are skipped, though search speed is improved, the relevance ratio grows
-   less. */
+   not to perform TF-IDF tuning, `ESTCONDSIMPLE' specifies to use simplified phrase,
+   `ESTCONDROUGH' specifies to use rough phrase, `ESTCONDUNION' specifies to use union phrase,
+   `ESTCONDISECT' specifies to use intersection phrase, `ESTCONDSCFB' specifies to feed back
+   scores (only for debugging).  Each option can be specified at the same time by bitwise or.  If
+   keys are skipped, though search speed is improved, the relevance ratio grows less. */
 void est_cond_set_options(ESTCOND *cond, int options);
 
 
@@ -386,6 +390,8 @@ typedef struct {                         /* type of structure for a database obj
   CURIA *kwddb;                          /* handle of the database for keywords */
   VILLA *listdb;                         /* handle of the database for document list */
   CBMAP *aidxs;                          /* map of attribute indexes */
+  CBLIST *pdocs;                         /* list of pseudo documents */
+  CBMAP *puris;                          /* map of URIs of pseudo documents */
   int ecode;                             /* last happened error code */
   int fatal;                             /* whether to have a fatal error */
   int dseq;                              /* sequence for document IDs */
@@ -697,25 +703,32 @@ int est_db_scan_doc(ESTDB *db, ESTDOC *doc, ESTCOND *cond);
 
 /* Set the maximum size of the cache memory of a database.
    `db' specifies a database object.
-   `size' specifies the maximum size of the index cache.  By default, it is 64MB.  If it is not
-   more than 0, the current size is not changed.
+   `size' specifies the maximum size of the index cache.  By default, it is 64MB.  If it is
+   negative, the current size is not changed.
    `anum' specifies the maximum number of cached records for document attributes.  By default, it
-   is 8192.  If it is not more than 0, the current size is not changed.
+   is 8192.  If it is negative, the current size is not changed.
    `tnum' specifies the maximum number of cached records for document texts.  By default, it is
-   1024.  If it is not more than 0, the current size is not changed.
+   1024.  If it is negative, the current size is not changed.
    `rnum' specifies the maximum number of cached records for occurrence results.  By default, it
-   is 256.  If it is not more than 0, the current size is not changed. */
+   is 256.  If it is negative, the current size is not changed. */
 void est_db_set_cache_size(ESTDB *db, size_t size, int anum, int tnum, int rnum);
 
 
+/* Add a pseudo index directory to a database.
+   `db' specifies a database object.
+   `path' specifies the path of a pseudo index directory.
+   The return value is true if success, else it is false. */
+int est_db_add_pseudo_index(ESTDB *db, const char *path);
+
+
 
 /*************************************************************************************************
  * features for experts
  *************************************************************************************************/
 
 
-#define _EST_VERSION   "1.3.6"
-#define _EST_LIBVER    821
+#define _EST_VERSION   "1.4.2"
+#define _EST_LIBVER    827
 #define _EST_PROTVER   "1.0"
 
 #define _EST_PROJURL   "http://hyperestraier.sourceforge.net/"
