@@ -30,7 +30,6 @@
 #define LOCKRETRYNUM   16                /* number of retries when locking failure */
 #define MISSRETRYNUM   3                 /* number of retries when missing documents */
 #define MISSINCRATIO   8                 /* ratio of increment number when missing */
-#define DEFPERPAGE     10                /* default number of show documents per page */
 #define NAVIPAGES      10                /* number of pages in paging navigation */
 #define SPCACHEMNUM    1048576           /* max number of the special cache */
 
@@ -49,7 +48,9 @@ const char *g_logfile = NULL;            /* path of the log file */
 int g_lockindex = FALSE;                 /* whether to perform file locking to the database */
 const CBLIST *g_replexprs = NULL;        /* list of URI replacement expressions */
 int g_showlreal = FALSE;                 /* wether to show local real paths */
+const char *g_perpage = NULL;            /* parameters for the per-page select box */
 int g_attrselect = FALSE;                /* whether to use select boxes for extension form */
+const CBLIST *g_genrechecks = NULL;      /* list of checkboxes of genre attributes */
 int g_showscore = FALSE;                 /* whether to show scores */
 const CBLIST *g_extattrs = NULL;         /* list of extra attributes of each document */
 int g_snipwwidth = -1;                   /* whole width of the snippet */
@@ -58,7 +59,7 @@ int g_snipawidth = -1;                   /* width around each highlighted word *
 int g_condgstep = -1;                    /* step of N-gram */
 int g_dotfidf = FALSE;                   /* whether to do TF-IDF tuning */
 int g_scancheck = -1;                    /* number of checked documents by scanning */
-int g_smplphrase = FALSE;                /* whether to use simplified phrase */
+int g_phraseform = 0;                    /* mode of phrase form */
 int g_candetail = FALSE;                 /* whether to show detail link */
 int g_auxmin = -1;                       /* minimum hits to adopt the auxiliary index */
 int g_smlrvnum = -1;                     /* number of elements of a vecter for similarity */
@@ -79,6 +80,7 @@ const char *p_order = NULL;              /* ordering attribute */
 int p_perpage = 0;                       /* number of show documents per page */
 int p_clip = 0;                          /* lower limit of similarity eclipse */
 int p_qxpnd = FALSE;                     /* whether to perform query expansion */
+int p_gmasks = 0;                        /* masks for genre attributes */
 int p_cinc = 0;                          /* ID of the parent of shown clipped documents */
 int p_prec = FALSE;                      /* whether to search more precisely */
 int p_pagenum = 0;                       /* number of the page */
@@ -136,6 +138,7 @@ int main(int argc, char **argv){
     p_perpage = 0;
     p_clip = 0;
     p_qxpnd = FALSE;
+    p_gmasks = 0;
     p_cinc = 0;
     p_prec = FALSE;
     p_pagenum = 0;
@@ -152,11 +155,11 @@ int main(int argc, char **argv){
 
 /* real main routine */
 static int realmain(int argc, char **argv){
-  CBLIST *lines, *rlist, *alist;
+  CBLIST *lines, *plist, *rlist, *glist, *alist;
   CBMAP *params;
   const char *rp;
-  char *tmp, *wp;
-  int i, ecode;
+  char *tmp, *wp, numbuf[NUMBUFSIZ];
+  int i, len, ecode;
   /* set configurations */
   est_proc_env_reset();
   setvbuf(stdout, g_outbuf, _IOFBF, OUTBUFSIZ);
@@ -171,8 +174,12 @@ static int realmain(int argc, char **argv){
   g_conffile = tmp;
   if(!(lines = cbreadlines(g_conffile))) showerror("the configuration file is missing.");
   cbglobalgc(lines, (void (*)(void *))cblistclose);
+  plist = cblistopen();
+  cbglobalgc(plist, (void (*)(void *))cblistclose);
   rlist = cblistopen();
   cbglobalgc(rlist, (void (*)(void *))cblistclose);
+  glist = cblistopen();
+  cbglobalgc(glist, (void (*)(void *))cblistclose);
   alist = cblistopen();
   cbglobalgc(alist, (void (*)(void *))cblistclose);
   for(i = 0; i < cblistnum(lines); i++){
@@ -187,16 +194,26 @@ static int realmain(int argc, char **argv){
       g_logfile = skiplabel(rp);
     } else if(cbstrfwimatch(rp, "lockindex:")){
       if(!cbstricmp(skiplabel(rp), "true")) g_lockindex = TRUE;
+    } else if(cbstrfwimatch(rp, "pseudoindex:")){
+      rp = skiplabel(rp);
+      if(*rp != '\0') cblistpush(plist, rp, -1);
     } else if(cbstrfwimatch(rp, "replace:")){
-      cblistpush(rlist, skiplabel(rp), -1);
+      rp = skiplabel(rp);
+      if(*rp != '\0') cblistpush(rlist, rp, -1);
     } else if(cbstrfwimatch(rp, "showlreal:")){
       if(!cbstricmp(skiplabel(rp), "true")) g_showlreal = TRUE;
+    } else if(cbstrfwimatch(rp, "perpage:")){
+      g_perpage = skiplabel(rp);
     } else if(cbstrfwimatch(rp, "attrselect:")){
       if(!cbstricmp(skiplabel(rp), "true")) g_attrselect = TRUE;
+    } else if(cbstrfwimatch(rp, "genrecheck:")){
+      rp = skiplabel(rp);
+      if(*rp != '\0') cblistpush(glist, rp, -1);
     } else if(cbstrfwimatch(rp, "showscore:")){
       if(!cbstricmp(skiplabel(rp), "true")) g_showscore = TRUE;
     } else if(cbstrfwimatch(rp, "extattr:")){
-      cblistpush(alist, skiplabel(rp), -1);
+      rp = skiplabel(rp);
+      if(*rp != '\0') cblistpush(alist, rp, -1);
     } else if(cbstrfwimatch(rp, "snipwwidth:")){
       g_snipwwidth = atoi(skiplabel(rp));
     } else if(cbstrfwimatch(rp, "sniphwidth:")){
@@ -209,8 +226,8 @@ static int realmain(int argc, char **argv){
       if(!cbstricmp(skiplabel(rp), "true")) g_dotfidf = TRUE;
     } else if(cbstrfwimatch(rp, "scancheck:")){
       g_scancheck = atoi(skiplabel(rp));
-    } else if(cbstrfwimatch(rp, "smplphrase:")){
-      if(!cbstricmp(skiplabel(rp), "true")) g_smplphrase = TRUE;
+    } else if(cbstrfwimatch(rp, "phraseform:")){
+      g_phraseform = atoi(skiplabel(rp));
     } else if(cbstrfwimatch(rp, "candetail:")){
       if(!cbstricmp(skiplabel(rp), "true")) g_candetail = TRUE;
     } else if(cbstrfwimatch(rp, "auxmin:")){
@@ -239,12 +256,15 @@ static int realmain(int argc, char **argv){
   if(!g_topfile) showerror("topfile is undefined.");
   if(!g_logfile) showerror("logfile is undefined.");
   g_replexprs = rlist;
+  if(!g_perpage) showerror("perpage is undefined.");
+  g_genrechecks = glist;
   g_extattrs = alist;
   if(g_snipwwidth < 0) showerror("snipwwidth is undefined.");
   if(g_sniphwidth < 0) showerror("sniphwidth is undefined.");
   if(g_snipawidth < 0) showerror("snipawidth is undefined.");
   if(g_condgstep < 1) showerror("condgstep is undefined.");
   if(g_scancheck < 0) showerror("scancheck is undefined.");
+  if(g_phraseform < 1) showerror("phraseform is undefined.");
   if(!g_smlrtune) showerror("smlrtune is undefined.");
   if(!g_spcache) showerror("spcache is undefined.");
   if(g_wildmax < 0) showerror("wildmax is undefined.");
@@ -281,9 +301,15 @@ static int realmain(int argc, char **argv){
     p_order++;
   }
   if((rp = cbmapget(params, "perpage", -1, NULL)) != NULL) p_perpage = atoi(rp);
-  if(p_perpage < 1) p_perpage = DEFPERPAGE;
+  if(p_perpage < 1) p_perpage = atoi(g_perpage);
   if((rp = cbmapget(params, "clip", -1, NULL)) != NULL) p_clip = atoi(rp);
   if((rp = cbmapget(params, "qxpnd", -1, NULL)) != NULL) p_qxpnd = atoi(rp);
+  for(i = 0; i < sizeof(int) * 8 - 1; i++){
+    len = sprintf(numbuf, "genre%d", i + 1);
+    if((rp = cbmapget(params, numbuf, len, NULL)) != NULL) p_gmasks |= 1 << i;
+  }
+  if((rp = cbmapget(params, "gmasks", -1, NULL)) != NULL) p_gmasks = atoi(rp);
+  if(p_gmasks == 0) p_gmasks = -1;
   if((rp = cbmapget(params, "cinc", -1, NULL)) != NULL) p_cinc = atoi(rp);
   if((rp = cbmapget(params, "prec", -1, NULL)) != NULL) p_prec = atoi(rp) > 0;
   if((rp = cbmapget(params, "detail", -1, NULL)) != NULL) p_detail = atoi(rp);
@@ -326,6 +352,9 @@ static int realmain(int argc, char **argv){
     }
     if(!g_db) showerror("the index is being updated now.");
     cbglobalgc(g_db, (void (*)(void *))myestdbclose);
+    for(i = 0; i < cblistnum(plist); i++){
+      est_db_add_pseudo_index(g_db, cblistval(plist, i, NULL));
+    }
     if(g_spcache[0] != '\0') est_db_set_special_cache(g_db, g_spcache, SPCACHEMNUM);
     est_db_set_wildmax(g_db, g_wildmax);
   }
@@ -561,9 +590,10 @@ static void showpage(void){
   ESTDOC **docs;
   CBMAP *hints, *allkwd, *dockwd;
   CBLIST *elems;
-  const char *rp, *vbuf;
+  CBDATUM *datum;
+  const char *rp, *pv, *vbuf;
   char *tmp, numbuf[NUMBUFSIZ];
-  int i, tnum, max, *res, rnum, hits, sc, dnum, miss, len, scnum;
+  int i, tnum, max, *res, rnum, hits, sc, dnum, miss, check, len, scnum;
   printf("Cache-Control: no-cache, must-revalidate, no-transform\r\n");
   printf("Pragma: no-cache\r\n");
   printf("Content-Disposition: inline; filename=%s\r\n", g_scriptname);
@@ -582,6 +612,27 @@ static void showpage(void){
       est_cond_add_attr(cond, p_attr);
     }
   }
+  if(cblistnum(g_genrechecks) > 0){
+    for(i = 0; i < cblistnum(g_genrechecks); i++){
+      if(!(p_gmasks & (1 << i))){
+        datum = cbdatumopen("@genre STROREQ", -1);
+        for(i = 0; i < cblistnum(g_genrechecks); i++){
+          if(p_gmasks & (1 << i)){
+            rp = cblistval(g_genrechecks, i, NULL);
+            cbdatumcat(datum, " ", 1);
+            if((pv = strstr(rp, "{{!}}")) != NULL){
+              cbdatumcat(datum, rp, pv - rp);
+            } else {
+              cbdatumcat(datum, rp, -1);
+            }
+          }
+        }
+        est_cond_add_attr(cond, cbdatumptr(datum));
+        cbdatumclose(datum);
+        break;
+      }
+    }
+  }
   if(p_order[0] != '\0') est_cond_set_order(cond, p_order);
   switch(g_condgstep){
   case 1:
@@ -598,7 +649,20 @@ static void showpage(void){
     break;
   }
   if(!g_dotfidf) est_cond_set_options(cond, ESTCONDNOIDF);
-  if(g_smplphrase) est_cond_set_options(cond, ESTCONDSIMPLE);
+  switch(g_phraseform){
+  case 2:
+    est_cond_set_options(cond, ESTCONDSIMPLE);
+    break;
+  case 3:
+    est_cond_set_options(cond, ESTCONDROUGH);
+    break;
+  case 4:
+    est_cond_set_options(cond, ESTCONDUNION);
+    break;
+  case 5:
+    est_cond_set_options(cond, ESTCONDISECT);
+    break;
+  }
   if(g_showscore) est_cond_set_options(cond, ESTCONDSCFB);
   est_cond_set_auxiliary(cond, p_prec ? -1 :
                          (g_auxmin > p_perpage * 1.3 + 1 ? g_auxmin : p_perpage * 1.3 + 1));
@@ -621,15 +685,16 @@ static void showpage(void){
     docs = cbmalloc(rnum * sizeof(ESTDOC *) + 1);
     dnum = 0;
     miss = 0;
+    check = g_scancheck;
     for(i = 0; i < rnum; i++){
       docs[dnum] = est_db_get_doc(g_db, res[i],
-                                  dnum < p_pagenum * p_perpage || g_scancheck > 0 ? 0 :
+                                  dnum < p_pagenum * p_perpage || check > 0 ? 0 :
                                   ESTGDNOATTR | ESTGDNOTEXT | ESTGDNOKWD);
       if(!docs[dnum]){
         miss++;
         continue;
       }
-      if(g_scancheck > 0 && p_phrase[0] != '[' && !est_db_scan_doc(g_db, docs[dnum], cond)){
+      if(check > 0 && p_phrase[0] != '[' && !est_db_scan_doc(g_db, docs[dnum], cond)){
         est_doc_delete(docs[dnum]);
         miss++;
         continue;
@@ -639,7 +704,7 @@ static void showpage(void){
         est_doc_add_attr(docs[dnum], DATTRSCORE, numbuf);
       }
       dnum++;
-      g_scancheck--;
+      check--;
     }
     if((tnum <= MISSRETRYNUM && miss > 0 && max <= rnum && dnum < p_pagenum * p_perpage + 1) ||
        (p_pagenum == 1 && tnum == 0 && (hits < g_auxmin || hits < p_perpage) &&
@@ -716,7 +781,8 @@ static void showpage(void){
 
 /* show the form */
 static void showform(void){
-  int i;
+  const char *rp, *pv;
+  int i, start, end, step;
   xmlprintf("<div id=\"estform\" class=\"estform\">\n");
   xmlprintf("<form action=\"%@\" method=\"get\" id=\"form_self\">\n", g_scriptname);
   xmlprintf("<div class=\"form_basic\">\n");
@@ -728,8 +794,26 @@ static void showform(void){
             ++g_tabidx);
   xmlprintf("</div>\n");
   xmlprintf("<div class=\"form_extension\">\n");
+  start = atoi(g_perpage);
+  if((rp = strchr(g_perpage, ' ')) != NULL || (rp = strchr(g_perpage, '\t')) != NULL){
+    while(*rp == ' ' || *rp == '\t'){
+      rp++;
+    }
+    end = atoi(rp);
+    if((rp = strchr(rp, ' ')) != NULL || (rp = strchr(rp, '\t')) != NULL){
+      while(*rp == ' ' || *rp == '\t'){
+        rp++;
+      }
+      step = atoi(rp);
+    } else {
+      step = start;
+    }
+  } else {
+    end = start * 10;
+    step = start;
+  }
   xmlprintf("<select name=\"perpage\" id=\"perpage\" tabindex=\"%d\">\n", ++g_tabidx);
-  for(i = 10; i <= 100; i += 10){
+  for(i = start; i <= end; i += step){
     xmlprintf("<option value=\"%d\"%s>%d</option>\n",
               i, i == p_perpage ? " selected=\"selected\"" : "", i);
   }
@@ -816,6 +900,18 @@ static void showform(void){
               p_qxpnd ? " checked=\"checked\"" : "", ++g_tabidx);
   }
   xmlprintf("</div>\n");
+  if(cblistnum(g_genrechecks) > 0){
+    xmlprintf("<div class=\"form_genrecheck\">\n");
+    for(i = 0; i < cblistnum(g_genrechecks); i++){
+      rp = cblistval(g_genrechecks, i, NULL);
+      if((pv = strstr(rp, "{{!}}")) != NULL) rp = pv + 5;
+      xmlprintf("<input type=\"checkbox\" name=\"genre%d\" value=\"on\"%s id=\"genre%d\""
+                " class=\"checkbox\" tabindex=\"%d\" accesskey=\"5\" />",
+                i + 1, p_gmasks & (1 << i) ? " checked=\"checked\"" : "", i + 1, ++g_tabidx);
+      xmlprintf("<label for=\"genre%d\" class=\"genrecheck\">:%s</label>\n", i + 1, rp);
+    }
+    xmlprintf("</div>\n");
+  }
   xmlprintf("</form>\n");
   xmlprintf("</div>\n");
 }
@@ -901,9 +997,9 @@ static void showresult(ESTDOC **docs, int dnum, CBMAP *hints, ESTCOND *cond, int
     for(i = 0; i < scnum && i < g_relkeynum; i++){
       if(i > 0) xmlprintf(", ");
       xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-                "&amp;clip=%d&amp;qxpnd=%d&amp;prec=%d\" class=\"rword\">%@</a>",
+                "&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;prec=%d\" class=\"rword\">%@</a>",
                 g_scriptname, scores[i].word, p_attr, p_attrval, p_order,
-                p_perpage, p_clip, p_qxpnd, p_prec, scores[i].word);
+                p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec, scores[i].word);
     }
     xmlprintf("</div>\n");
   }
@@ -933,15 +1029,16 @@ static void showresult(ESTDOC **docs, int dnum, CBMAP *hints, ESTCOND *cond, int
   xmlprintf("<div class=\"paging\">\n");
   if(clip > 0)
     xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-              "&amp;clip=%d&amp;qxpnd=%d&amp;cinc=-1&amp;prec=%d&amp;pagenum=%d&amp;similar=%d\""
-              " class=\"navi\">Include %d Clipped</a>\n",
+              "&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;cinc=-1&amp;prec=%d&amp;pagenum=%d"
+              "&amp;similar=%d\" class=\"navi\">Include %d Clipped</a>\n",
               g_scriptname, myphrase, p_attr, p_attrval, p_order,
-              p_perpage, p_clip, p_qxpnd, p_prec, p_pagenum, p_similar, clip);
+              p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec, p_pagenum, p_similar, clip);
   if(p_pagenum > 1){
     xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-              "&amp;clip=%d&amp;qxpnd=%d&amp;prec=%d&amp;pagenum=%d&amp;similar=%d\""
-              " class=\"navi\">PREV</a>\n", g_scriptname, myphrase, p_attr, p_attrval, p_order,
-              p_perpage, p_clip, p_qxpnd, p_prec, p_pagenum - 1, p_similar);
+              "&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;prec=%d&amp;pagenum=%d"
+              "&amp;similar=%d\" class=\"navi\">PREV</a>\n",
+              g_scriptname, myphrase, p_attr, p_attrval, p_order,
+              p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec, p_pagenum - 1, p_similar);
   } else {
     xmlprintf("<span class=\"void\">PREV</span>\n");
   }
@@ -953,25 +1050,27 @@ static void showresult(ESTDOC **docs, int dnum, CBMAP *hints, ESTCOND *cond, int
         printf("<span class=\"pnow\">%d</span>\n", i);
       } else {
         xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-                  "&amp;clip=%d&amp;qxpnd=%d&amp;prec=%d&amp;pagenum=%d&amp;similar=%d\""
-                  " class=\"pnum\">%d</a>\n", g_scriptname, myphrase, p_attr, p_attrval,
-                  p_order, p_perpage, p_clip, p_qxpnd, p_prec, i, p_similar, i);
+                  "&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;prec=%d&amp;pagenum=%d"
+                  "&amp;similar=%d\" class=\"pnum\">%d</a>\n",
+                  g_scriptname, myphrase, p_attr, p_attrval,
+                  p_order, p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec, i, p_similar, i);
       }
     }
   }
   if(snum < dnum){
     xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-              "&amp;clip=%d&amp;qxpnd=%d&amp;prec=%d&amp;pagenum=%d&amp;similar=%d\""
-              " class=\"navi\">NEXT</a>\n", g_scriptname, myphrase, p_attr, p_attrval, p_order,
-              p_perpage, p_clip, p_qxpnd, p_prec, p_pagenum + 1, p_similar);
+              "&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;prec=%d&amp;pagenum=%d"
+              "&amp;similar=%d\" class=\"navi\">NEXT</a>\n",
+              g_scriptname, myphrase, p_attr, p_attrval, p_order,
+              p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec, p_pagenum + 1, p_similar);
   } else {
     xmlprintf("<span class=\"void\">NEXT</span>\n");
     if(est_cond_auxiliary_word(cond, ""))
       xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-                "&amp;prec=1&amp;clip=%d&amp;qxpnd=%d&amp;similar=%d\" class=\"navi\">"
-                "Search More Precisely</a>\n",
+                "&amp;prec=1&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;similar=%d\""
+                " class=\"navi\">Search More Precisely</a>\n",
                 g_scriptname, myphrase, p_attr, p_attrval, p_order,
-                p_perpage, p_clip, p_qxpnd, p_similar);
+                p_perpage, p_clip, p_qxpnd, p_gmasks, p_similar);
   }
   xmlprintf("</div>\n");
   xmlprintf("</div>\n");
@@ -1082,12 +1181,13 @@ static void showdoc(ESTDOC *doc, const CBLIST *words, CBMAP *cnames, int detail,
   xmlprintf("<span class=\"doc_link\">%@</span>\n", turi);
   if(g_candetail)
     xmlprintf("- <a href=\"%@?phrase=%?&amp;detail=%d&amp;perpage=%d&amp;clip=%d"
-              "&amp;qxpnd=%d&amp;prec=%d\" class=\"detail\">[detail]</a>\n", g_scriptname,
-              p_similar > 0 ? "" : p_phrase, id, p_perpage, p_clip, p_qxpnd, p_prec);
+              "&amp;qxpnd=%d&amp;gmasks=%d&amp;prec=%d\" class=\"detail\">[detail]</a>\n",
+              g_scriptname, p_similar > 0 ? "" : p_phrase, id,
+              p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec);
   if(g_smlrvnum > 0)
-    xmlprintf("- <a href=\"%@?similar=%d&amp;perpage=%d&amp;clip=%d&amp;qxpnd=%d&amp;prec=%d\""
-              " class=\"similar\">[similar]</a>\n",
-              g_scriptname, id, p_perpage, p_clip, p_qxpnd, p_prec);
+    xmlprintf("- <a href=\"%@?similar=%d&amp;perpage=%d&amp;clip=%d&amp;qxpnd=%d"
+              "&amp;gmasks=%d&amp;prec=%d\" class=\"similar\">[similar]</a>\n",
+              g_scriptname, id, p_perpage, p_clip, p_qxpnd, p_gmasks, p_prec);
   xmlprintf("</dd>\n");
   xmlprintf("</dl>\n");
   if(!detail && shadows && snum > 0){
@@ -1096,10 +1196,10 @@ static void showdoc(ESTDOC *doc, const CBLIST *words, CBMAP *cnames, int detail,
         xmlprintf("<div class=\"doc_clip\">\n");
         xmlprintf("<p>%d more documents clipped ... ", (snum - i) / 2);
         xmlprintf("<a href=\"%@?phrase=%?&amp;attr=%?&amp;attrval=%?&amp;order=%?&amp;perpage=%d"
-                  "&amp;clip=%d&amp;qxpnd=%d&amp;cinc=%d&amp;prec=%d&amp;pagenum=%d"
+                  "&amp;clip=%d&amp;qxpnd=%d&amp;gmasks=%d&amp;cinc=%d&amp;prec=%d&amp;pagenum=%d"
                   "&amp;similar=%d#doc_%d\" class=\"include\">[include]</a>",
                   g_scriptname, p_similar > 0 ? "" : p_phrase, p_attr, p_attrval, p_order,
-                  p_perpage, p_clip, p_qxpnd, id, p_prec, p_pagenum, p_similar, id);
+                  p_perpage, p_clip, p_qxpnd, p_gmasks, id, p_prec, p_pagenum, p_similar, id);
         xmlprintf("</p>\n");
         xmlprintf("</div>\n");
         *clipp += (snum - i) / 2;
