@@ -130,6 +130,7 @@ static void setsignals(void){
   est_signal(2, sigtermhandler);
   est_signal(3, sigtermhandler);
   est_signal(13, SIG_IGN);
+  est_signal(14, SIG_IGN);
   est_signal(15, sigtermhandler);
   g_sigterm = FALSE;
 }
@@ -723,7 +724,7 @@ static int procfetch(const char *url){
   links = cblistopen();
   doc = est_doc_new();
   if(!fetch_document(url, g_pxhost, g_pxport, g_timeout, -1, NULL, &code, raw, heads,
-                     links, doc, g_inputlang)){
+                     links, NULL, doc, g_inputlang)){
     log_print(LL_WARN, "could not get: %d: %s", code, url);
     est_doc_delete(doc);
     cblistclose(links);
@@ -829,7 +830,7 @@ static void seedurldocs(WAVER *waver, const char *url, int depth, double bias, C
   doc = est_doc_new();
   log_print(LL_INFO, "fetching: %d: %s", depth, url);
   fetch_document(url, waver->pxhost, waver->pxport, waver->timeout * 2, 0,
-                 waver->mtrules, &code, NULL, NULL, links, doc, waver->language);
+                 waver->mtrules, &code, NULL, NULL, links, waver->unrules, doc, waver->language);
   if(code == 200 && !est_doc_is_empty(doc)){
     log_print(LL_INFO, "seeding: %.3f: %s", bias, url);
     kwords = est_morph_etch_doc(doc, waver->seedkeynum);
@@ -950,7 +951,7 @@ static void *geturldoc(void *args){
   doc = est_doc_new();
   log_print(LL_INFO, "[%d]: fetching: %d: %s", thid, myargs->depth, url);
   fetch_document(url, waver->pxhost, waver->pxport, waver->timeout, myargs->mdate,
-                 waver->mtrules, &code, raw, heads, links, doc, waver->language);
+                 waver->mtrules, &code, raw, heads, links, waver->unrules, doc, waver->language);
   if(g_sigterm){
     log_print(LL_WARN, "[%d]: terminated: %s", thid, url);
     if(pthread_mutex_lock(&g_mutex) == 0){
