@@ -96,7 +96,7 @@ public class Cmd {
     stderr.println("  inform db");
     stderr.println("  optimize [-onp] [-ond] db");
     stderr.println("  merge [-cl] db target");
-    stderr.println("  search [-vu|-va|-vf|-vs] [-gs|-gf|-ga] [-cd] [-ni] [-sf]" +
+    stderr.println("  search [-vu|-va|-vf|-vs] [-gs|-gf|-ga] [-cd] [-ni] [-sf|-sfr|-sfu|-sfi]" +
                    " [-attr expr] [-ord expr] [-max num] [-sk num] db [phrase]");
     stderr.println("");
     System.exit(1);
@@ -319,6 +319,12 @@ public class Cmd {
           opts |= Condition.NOIDF;
         } else if(arg.equals("-sf")){
           opts |= Condition.SIMPLE;
+        } else if(arg.equals("-sfr")){
+          opts |= Condition.ROUGH;
+        } else if(arg.equals("-sfu")){
+          opts |= Condition.UNION;
+        } else if(arg.equals("-sfi")){
+          opts |= Condition.ISECT;
         } else if(arg.equals("-attr")){
           if(++i >= args.length) usage();
           attrs.add(args[i]);
