@@ -47,6 +47,12 @@ public class Condition {
   public static final int NOIDF = 1 << 4;
   /** option: with the simplified phrase */
   public static final int SIMPLE = 1 << 10;
+  /** option: with the rough phrase */
+  public static final int ROUGH = 1 << 11;
+  /** option: with the union phrase */
+  public static final int UNION = 1 << 15;
+  /** option: with the intersection phrase */
+  public static final int ISECT = 1 << 16;
   /** eclipse tuning: consider URL */
   public static final double ECLSIMURL = 10.0;
   /** eclipse tuning: on server basis */
@@ -110,8 +116,10 @@ public class Condition {
    * `Condition.USUAL', which is the default, specifies that it checks N-gram keys with skipping
    * one key, `Condition.FAST' skips two keys, `Condition.AGITO' skips three keys,
    * `Condition.NOIDF' specifies not to perform TF-IDF tuning, `Condition.SIMPLE' specifies to
-   * use simplified phrase.  Each option can be specified at the same time by bitwise or.  If
-   * keys are skipped, though search speed is improved, the relevance ratio grows less.
+   * use simplified phrase, `Condition.ROUGH' specifies to use rough phrase, `Condition.UNION'
+   * specifies to use union phrase, `Condition.ISECT' specifies to use intersection phrase.  Each
+   * option can be specified at the same time by bitwise or.  If keys are skipped, though search
+   * speed is improved, the relevance ratio grows less.
    */
   public native void set_options(int options);
   /**
