@@ -123,7 +123,7 @@ public class Call {
     stderr.println("  optimize [-proxy host:port] [-tout num] [-auth user pass]" +
                    " nurl");
     stderr.println("  search [-proxy host:port] [-tout num] [-auth user pass]" +
-                   " [-sf] [-attr expr] [-ord expr] [-max num] [-sk num]" +
+                   " [-sf|-sfr|-sfu|-sfi] [-attr expr] [-ord expr] [-max num] [-sk num]" +
                    " [-dpt num] [-mask num] nurl [phrase]");
     stderr.println("  setuser [-proxy host:port] [-tout num] [-auth user pass]" +
                    " nurl name mode");
@@ -472,6 +472,12 @@ public class Call {
           authpass = args[i];
         } else if(arg.equals("-sf")){
           opts |= Condition.SIMPLE;
+        } else if(arg.equals("-sfr")){
+          opts |= Condition.ROUGH;
+        } else if(arg.equals("-sfu")){
+          opts |= Condition.UNION;
+        } else if(arg.equals("-sfi")){
+          opts |= Condition.ISECT;
         } else if(arg.equals("-attr")){
           if(++i >= args.length) usage();
           attrs.add(args[i]);
