@@ -106,7 +106,7 @@ int log_rotate(const char *rootdir, const char *path){
   char mypath[URIBUFSIZ], *wp, iobuf[IOBUFSIZ];
   int err, year, month, day, hour, minute, second, len;
   assert(rootdir && path);
-  if(!log_fp || fflush(log_fp) == -1) return FALSE;;
+  if(!log_fp || fflush(log_fp) == -1) return FALSE;
   err = FALSE;
   wp = mypath;
   if((ESTPATHCHR == '/' && path[0] == ESTPATHCHR) ||
@@ -131,7 +131,7 @@ int log_rotate(const char *rootdir, const char *path){
   if(fclose(ifp) == -1) err = TRUE;
   if(fseek(log_fp, 0, SEEK_SET) == -1 || fflush(log_fp) == -1) err = TRUE;
   if(ftruncate(fileno(log_fp), 0) == -1) err = TRUE;
-  return err ? FALSE : TRUE;;
+  return err ? FALSE : TRUE;
 }
 
 
@@ -250,6 +250,9 @@ int master_init(const char *rootdir){
     fprintf(ofp, "# name of the attribute of the special cache\n");
     fprintf(ofp, "specialcache:\n");
     fprintf(ofp, "\n");
+    fprintf(ofp, "# lower limit of cache usage to use the helper\n");
+    fprintf(ofp, "helpershift: 0.9\n");
+    fprintf(ofp, "\n");
     fprintf(ofp, "# maximum number of expansion of wild cards\n");
     fprintf(ofp, "wildmax: 256\n");
     fprintf(ofp, "\n");
@@ -285,8 +288,9 @@ int master_init(const char *rootdir){
     fprintf(ofp, "uiextattr: @author|Author\n");
     fprintf(ofp, "uiextattr: @mdate|Modification Date\n");
     fprintf(ofp, "\n");
-    fprintf(ofp, "# whether to use simplified search phrase (0:no, 1:yes)\n");
-    fprintf(ofp, "uismplphrase: 1\n");
+    fprintf(ofp, "# mode of phrase form"
+            " (1:usual, 2:simplified, 3:rough, 4:union: 5:intersection)\n");
+    fprintf(ofp, "uiphraseform: 2\n");
     fprintf(ofp, "\n");
     fprintf(ofp, "# tuning parameters for similarity search\n");
     fprintf(ofp, "uismlrtune: 16 1024 4096\n");
@@ -364,14 +368,14 @@ UMGR *umgr_new(const char *rootdir){
 int umgr_delete(UMGR *umgr){
   USER *user;
   const char *kbuf, *vbuf;
-  int err, ksiz;
+  int err;
   assert(umgr);
   log_print(LL_INFO, "finishing the user manager");
   err = FALSE;
   if(!umgr_sync(umgr)) err = TRUE;
   cbmapiterinit(umgr->users);
-  while((kbuf = cbmapiternext(umgr->users, &ksiz)) != NULL){
-    vbuf = cbmapget(umgr->users, kbuf, ksiz, NULL);
+  while((kbuf = cbmapiternext(umgr->users, NULL)) != NULL){
+    vbuf = cbmapiterval(kbuf, NULL);
     user = (USER *)vbuf;
     pthread_mutex_destroy(&(user->mutex));
     if(user->sess) cbmapclose(user->sess);
@@ -424,7 +428,7 @@ int umgr_sync(UMGR *umgr){
   USER *user;
   const char *kbuf, *vbuf;
   char path[URIBUFSIZ];
-  int err, ksiz;
+  int err;
   assert(umgr);
   log_print(LL_INFO, "saving the user list");
   sprintf(path, "%s%c%s", umgr->rootdir, ESTPATHCHR, USERFILE);
@@ -434,8 +438,8 @@ int umgr_sync(UMGR *umgr){
   }
   err = FALSE;
   cbmapiterinit(umgr->users);
-  while((kbuf = cbmapiternext(umgr->users, &ksiz)) != NULL){
-    vbuf = cbmapget(umgr->users, kbuf, ksiz, NULL);
+  while((kbuf = cbmapiternext(umgr->users, NULL)) != NULL){
+    vbuf = cbmapiterval(kbuf, NULL);
     user = (USER *)vbuf;
     fprintf(ofp, "%s\t%s\t%s\t%s\t%s\n",
             user->name, user->passwd, user->flags, user->fname, user->misc);
@@ -579,15 +583,15 @@ NMGR *nmgr_new(const char *rootdir){
 int nmgr_delete(NMGR *nmgr){
   NODE *node;
   const char *kbuf, *vbuf;
-  int err, ksiz, ecode;
+  int err, ecode;
   assert(nmgr);
   log_print(LL_INFO, "finishing the node manager");
   err = FALSE;
   if(!nmgr_sync(nmgr, FALSE)) err = TRUE;
   cbmapclose(nmgr->aidxs);
   cbmapiterinit(nmgr->nodes);
-  while((kbuf = cbmapiternext(nmgr->nodes, &ksiz)) != NULL){
-    vbuf = cbmapget(nmgr->nodes, kbuf, ksiz, NULL);
+  while((kbuf = cbmapiternext(nmgr->nodes, NULL)) != NULL){
+    vbuf = cbmapiterval(kbuf, NULL);
     node = (NODE *)vbuf;
     pthread_mutex_destroy(&(node->mutex));
     cbmapclose(node->links);
@@ -637,8 +641,8 @@ int nmgr_sync(NMGR *nmgr, int phis){
   log_print(LL_INFO, "synchronizing the node manager");
   err = FALSE;
   cbmapiterinit(nmgr->nodes);
-  while((kbuf = cbmapiternext(nmgr->nodes, &ksiz)) != NULL){
-    vbuf = cbmapget(nmgr->nodes, kbuf, ksiz, NULL);
+  while((kbuf = cbmapiternext(nmgr->nodes, NULL)) != NULL){
+    vbuf = cbmapiterval(kbuf, NULL);
     node = (NODE *)vbuf;
     est_mtdb_add_meta(node->db, NMKNAME, node->name);
     est_mtdb_add_meta(node->db, NMKLABEL, node->label);
@@ -661,7 +665,7 @@ int nmgr_sync(NMGR *nmgr, int phis){
     datum = cbdatumopen(NULL, -1);
     cbmapiterinit(node->links);
     while((kbuf = cbmapiternext(node->links, &ksiz)) != NULL){
-      vbuf = cbmapget(node->links, kbuf, ksiz, &vsiz);
+      vbuf = cbmapiterval(kbuf, &vsiz);
       cbdatumcat(datum, kbuf, ksiz);
       cbdatumcat(datum, "\t", 1);
       cbdatumcat(datum, vbuf, vsiz);
@@ -720,8 +724,8 @@ int nmgr_put(NMGR *nmgr, const char *name, int wmode, int options){
   }
   est_mtdb_set_informer(db, db_informer, NULL);
   cbmapiterinit(nmgr->aidxs);
-  while((cbuf = cbmapiternext(nmgr->aidxs, &csiz)) != NULL){
-    est_mtdb_add_attr_index(db, cbuf, *(int *)cbmapget(nmgr->aidxs, cbuf, csiz, NULL));
+  while((cbuf = cbmapiternext(nmgr->aidxs, NULL)) != NULL){
+    est_mtdb_add_attr_index(db, cbuf, *(int *)cbmapiterval(cbuf, NULL));
   }
   node.db = db;
   est_mtdb_add_meta(db, NMKNAME, name);
@@ -951,11 +955,10 @@ RESMAP *resmap_new(void){
 void resmap_delete(RESMAP *resmap){
   RESDOC *resdoc;
   const char *kbuf, *vbuf;
-  int ksiz;
   assert(resmap);
   cbmapiterinit(resmap->uris);
-  while((kbuf = cbmapiternext(resmap->uris, &ksiz)) != NULL){
-    vbuf = cbmapget(resmap->uris, kbuf, ksiz, NULL);
+  while((kbuf = cbmapiternext(resmap->uris, NULL)) != NULL){
+    vbuf = cbmapiterval(kbuf, NULL);
     resdoc = (RESDOC *)vbuf;
     if(resdoc->doc) est_doc_delete(resdoc->doc);
     if(resdoc->attrs) cbmapclose(resdoc->attrs);
@@ -1013,7 +1016,7 @@ RESDOC **resmap_list(RESMAP *resmap, int *nump, const char *order){
   RESDOC **resdocs;
   const char *kbuf, *vbuf, *otype, *rp;
   char *oname, *wp;
-  int i, ksiz, onlen;
+  int i, onlen;
   time_t tval;
   assert(resmap && nump);
   if(pthread_mutex_lock(&(resmap->mutex)) != 0){
@@ -1024,8 +1027,8 @@ RESDOC **resmap_list(RESMAP *resmap, int *nump, const char *order){
   resdocs = cbmalloc(*nump * sizeof(RESDOC) + 1);
   cbmapiterinit(resmap->uris);
   for(i = 0; i < *nump; i++){
-    kbuf = cbmapiternext(resmap->uris, &ksiz);
-    vbuf = cbmapget(resmap->uris, kbuf, ksiz, NULL);
+    kbuf = cbmapiternext(resmap->uris, NULL);
+    vbuf = cbmapiterval(kbuf, NULL);
     resdocs[i] = (RESDOC *)vbuf;
   }
   if(order){
