@@ -51,7 +51,13 @@
 #define NODEDIR        "_node"           /* name of the node directory */
 #define SESSDIR        "_sess"           /* name of the session directory */
 #define NULLDEV        "/dev/null"       /* path of null device */
-#define SEARCHHELPER   "estbutler search"  /* command name of the search helper */
+
+#define INFORMHELPER   "estbutler inform"    /* command name of the inform helper */
+#define SEARCHHELPER   "estbutler search"    /* command name of the search helper */
+#define GETDOCHELPER   "estbutler getdoc"    /* command name of the get_doc helper */
+#define GETDOCATTRHELPER  "estbutler getdocattr"  /* command name of the get_doc helper */
+#define ETCHDOCHELPER  "estbutler etchdoc"   /* command name of the etch_doc helper */
+#define URITOIDHELPER  "estbutler uritoid"   /* command name of the uri_to_id helper */
 
 #define MMKMAGIC       "magic"           /* meta key of the magic number of meta DB */
 #define MMKMAGVAL      "[ESTMASTER]"     /* value of the magic number of meta DB */
@@ -100,6 +106,20 @@ enum {                                   /* enumeration for scoring expression m
   SE_ASIS = 4                            /* asis */
 };
 
+enum {                                   /* enumeration for UI operations */
+  MM_SCORE = 1,                          /* score */
+  MM_SCRK = 2,                           /* score and rank */
+  MM_RANK = 3                            /* rank */
+};
+
+enum {                                   /* enumeration for phrase mode */
+  PM_USUAL = 1,                          /* usual phrase */
+  PM_SIMPLE = 2,                         /* simplified phrase */
+  PM_ROUGH = 3,                          /* rough phrase */
+  PM_UNION = 4,                          /* union phrase */
+  PM_ISECT = 5                           /* intersection phrase */
+};
+
 typedef struct {                         /* type of structure for a user object */
   char *name;                            /* unique name */
   char *passwd;                          /* encrypted password */
