@@ -83,7 +83,7 @@ sub usage {
     printf(STDERR "  %s inform db\n", $0);
     printf(STDERR "  %s optimize [-onp] [-ond] db\n", $0);
     printf(STDERR "  %s merge [-cl] db target\n", $0);
-    printf(STDERR "  %s search [-vu|-va|-vf|-vs] [-gs|-gf|-ga] [-cd] [-ni] [-sf]" .
+    printf(STDERR "  %s search [-vu|-va|-vf|-vs] [-gs|-gf|-ga] [-cd] [-ni] [-sf|-sfr|-sfu|-sfi]" .
            " [-attr expr] [-ord expr] [-max num] [-sk num] db [phrase]\n", $0);
     printf(STDERR "\n");
     exit(1);
@@ -325,6 +325,14 @@ sub runsearch {
                 $cd = TRUE;
             } elsif($ARGV[$i] eq "-ni"){
                 $opts |= Condition::NOIDF;
+            } elsif($ARGV[$i] eq "-sf"){
+                $opts |= Condition::SIMPLE;
+            } elsif($ARGV[$i] eq "-sfr"){
+                $opts |= Condition::ROUGH;
+            } elsif($ARGV[$i] eq "-sfu"){
+                $opts |= Condition::UNION;
+            } elsif($ARGV[$i] eq "-sfi"){
+                $opts |= Condition::ISECT;
             } elsif($ARGV[$i] eq "-attr"){
                 usage() if(++$i >= scalar(@ARGV));
                 push(@attrs, $ARGV[$i]);
