@@ -253,6 +253,9 @@ use constant {
     AGITO => 1 << 3,
     NOIDF => 1 << 4,
     SIMPLE => 1 << 10,
+    ROUGH => 1 << 11,
+    UNION => 1 << 15,
+    ISECT => 1 << 16,
     ECLSIMURL => 10.0,
     ECLSERV => 100.0,
     ECLDIR => 101.0,
@@ -962,6 +965,21 @@ sub set_cache_size {
 }
 
 
+sub add_pseudo_index {
+    my $self = shift;
+    my $path = shift;
+    if(scalar(@_) != 0 || !defined($path)){
+        croak(__FILE__ . ": invalid parameter") if($Estraier::DEBUG);
+        return undef;
+    }
+    unless($$self[0]){
+        $$self[1] = ERRMISC;
+        return undef;
+    }
+    return Estraier::db_add_pseudo_index($$self[0], $path);
+}
+
+
 sub set_wildmax {
     my $self = shift;
     my $num = shift;
