@@ -75,7 +75,7 @@ def usage()
   STDERR.printf("  %s inform db\n", $0)
   STDERR.printf("  %s optimize [-onp] [-ond] db\n", $0)
   STDERR.printf("  %s merge [-cl] db target\n", $0)
-  STDERR.printf("  %s search [-vu|-va|-vf|-vs] [-gs|-gf|-ga] [-cd] [-ni] [-sf]" \
+  STDERR.printf("  %s search [-vu|-va|-vf|-vs] [-gs|-gf|-ga] [-cd] [-ni] [-sf|-sfr|-sfu|-sfi]" \
                 " [-attr expr] [-ord expr] [-max num] [-sk num] db [phrase]\n", $0)
   STDERR.printf("\n")
   exit(1)
@@ -326,6 +326,12 @@ def runsearch(args)
         opts |= Condition::NOIDF
       elsif args[i] == "-sf"
         opts |= Condition::SIMPLE
+      elsif args[i] == "-sfr"
+        opts |= Condition::ROUGH
+      elsif args[i] == "-sfu"
+        opts |= Condition::UNION
+      elsif args[i] == "-sfi"
+        opts |= Condition::ISECT
       elsif args[i] == "-attr"
         usage if (i += 1) >= args.length
         attrs.push(args[i])
