@@ -140,6 +140,12 @@ module Estraier
     NOIDF = 1 << 4
     # option: with the simplified phrase
     SIMPLE = 1 << 10
+    # option: with the rough phrase
+    ROUGH = 1 << 11
+    # option: with the union phrase
+    UNION = 1 << 15
+    # option: with the intersection phrase
+    ISECT = 1 << 16
     # eclipse tuning: consider URL
     ECLSIMURL = 10.0
     # eclipse tuning: on server basis
@@ -188,9 +194,10 @@ module Estraier
     # key, `Condition::USU', which is the default, specifies that it checks N-gram keys
     # with skipping one key, `Condition::FAST' skips two keys, `Condition::AGITO'
     # skips three keys, `Condition::NOIDF' specifies not to perform TF-IDF tuning,
-    # `Condition::SIMPLE' specifies to use simplified phrase.  Each option can be specified at
-    # the same time by bitwise or.  If keys are skipped, though search speed is improved, the
-    # relevance ratio grows less.
+    # `Condition::SIMPLE' specifies to use simplified phrase, `Condition::ROUGH' specifies to use
+    # rough phrase, `Condition::UNION' specifies to use union phrase, `Condition::ISECT' specifies
+    # to use intersection phrase.  Each option can be specified at the same time by bitwise or.
+    # If keys are skipped, though search speed is improved, the relevance ratio grows less.
     # The return value is always `nil'.
     def set_options(options)
       # native code ...
@@ -554,6 +561,12 @@ module Estraier
     def set_cache_size(size, anum, tnum, rnum)
       # native code ...
     end
+    # Add a pseudo index directory.
+    # `path' specifies the path of a pseudo index directory.
+    # The return value is true if success, else it is false.
+    def add_pseudo_index(path)
+      # native code ...
+    end
     # Set the maximum number of expansion of wild cards.
     # `num' specifies the maximum number of expansion of wild cards.
     # The return value is always `nil'.
