@@ -104,6 +104,7 @@ static VALUE db_size(VALUE vself);
 static VALUE db_search(VALUE vself, VALUE vcond);
 static VALUE db_scan_doc(VALUE vself, VALUE vdoc, VALUE vcond);
 static VALUE db_set_cache_size(VALUE vself, VALUE vsize, VALUE vanum, VALUE vtnum, VALUE vrnum);
+static VALUE db_add_pseudo_index(VALUE vself, VALUE vpath);
 static VALUE db_set_wildmax(VALUE vself, VALUE vnum);
 static VALUE db_set_informer(VALUE vself, VALUE vinformer);
 static VALUE cblisttoobj(const CBLIST *list);
@@ -244,8 +245,7 @@ static VALUE doc_set_score(VALUE vself, VALUE vscore){
   int score;
   vdoc = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdoc, ESTDOC, doc);
-  Check_Type(vscore, T_FIXNUM);
-  score = FIX2INT(vscore);
+  score = NUM2INT(vscore);
   if(score < 0) rb_raise(rb_eArgError, "invalid argument");
   est_doc_set_score(doc, score);
   return Qnil;
@@ -257,7 +257,7 @@ static VALUE doc_id(VALUE vself){
   ESTDOC *doc;
   vdoc = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdoc, ESTDOC, doc);
-  return INT2FIX(est_doc_id(doc));
+  return INT2NUM(est_doc_id(doc));
 }
 
 
@@ -311,9 +311,11 @@ static VALUE doc_cat_texts(VALUE vself){
 static VALUE doc_keywords(VALUE vself){
   VALUE vdoc;
   ESTDOC *doc;
+  CBMAP *kwords;
   vdoc = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdoc, ESTDOC, doc);
-  return cbmaptoobj(est_doc_keywords(doc));
+  if(!(kwords = est_doc_keywords(doc))) return Qnil;
+  return cbmaptoobj(kwords);
 }
 
 
@@ -344,12 +346,9 @@ static VALUE doc_make_snippet(VALUE vself, VALUE vwords,
   for(i = 0; i < len; i++){
     Check_Type(rb_ary_entry(vwords, i), T_STRING);
   }
-  Check_Type(vwwidth, T_FIXNUM);
-  Check_Type(vhwidth, T_FIXNUM);
-  Check_Type(vawidth, T_FIXNUM);
   words = objtocblist(vwords);
   snippet = est_doc_make_snippet(doc, words,
-                                 FIX2INT(vwwidth), FIX2INT(vhwidth), FIX2INT(vawidth));
+                                 NUM2INT(vwwidth), NUM2INT(vhwidth), NUM2INT(vawidth));
   vsnippet = rb_str_new2(snippet);
   free(snippet);
   cblistclose(words);
@@ -360,12 +359,15 @@ static VALUE doc_make_snippet(VALUE vself, VALUE vwords,
 static void cond_init(void){
   cls_cond = rb_define_class_under(mod_estraier, "Condition", rb_cObject);
   cls_cond_data = rb_define_class_under(mod_estraier, "Condition_data", rb_cObject);
-  rb_define_const(cls_cond, "SURE", INT2FIX(ESTCONDSURE));
-  rb_define_const(cls_cond, "USUAL", INT2FIX(ESTCONDUSUAL));
-  rb_define_const(cls_cond, "FAST", INT2FIX(ESTCONDFAST));
-  rb_define_const(cls_cond, "AGITO", INT2FIX(ESTCONDAGITO));
-  rb_define_const(cls_cond, "NOIDF", INT2FIX(ESTCONDNOIDF));
-  rb_define_const(cls_cond, "SIMPLE", INT2FIX(ESTCONDSIMPLE));
+  rb_define_const(cls_cond, "SURE", INT2NUM(ESTCONDSURE));
+  rb_define_const(cls_cond, "USUAL", INT2NUM(ESTCONDUSUAL));
+  rb_define_const(cls_cond, "FAST", INT2NUM(ESTCONDFAST));
+  rb_define_const(cls_cond, "AGITO", INT2NUM(ESTCONDAGITO));
+  rb_define_const(cls_cond, "NOIDF", INT2NUM(ESTCONDNOIDF));
+  rb_define_const(cls_cond, "SIMPLE", INT2NUM(ESTCONDSIMPLE));
+  rb_define_const(cls_cond, "ROUGH", INT2NUM(ESTCONDROUGH));
+  rb_define_const(cls_cond, "UNION", INT2NUM(ESTCONDUNION));
+  rb_define_const(cls_cond, "ISECT", INT2NUM(ESTCONDISECT));
   rb_define_const(cls_cond, "ECLSIMURL", rb_float_new(ESTECLSIMURL));
   rb_define_const(cls_cond, "ECLSERV", rb_float_new(ESTECLSERV));
   rb_define_const(cls_cond, "ECLDIR", rb_float_new(ESTECLDIR));
@@ -433,8 +435,7 @@ static VALUE cond_set_max(VALUE vself, VALUE vmax){
   int max;
   vcond = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(vmax, T_FIXNUM);
-  max = FIX2INT(vmax);
+  max = NUM2INT(vmax);
   if(max < 0) rb_raise(rb_eArgError, "invalid argument");
   est_cond_set_max(cond, max);
   return Qnil;
@@ -447,8 +448,7 @@ static VALUE cond_set_skip(VALUE vself, VALUE vskip){
   int skip;
   vcond = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(vskip, T_FIXNUM);
-  skip = FIX2INT(vskip);
+  skip = NUM2INT(vskip);
   if(skip < 0) rb_raise(rb_eArgError, "invalid argument");
   est_cond_set_skip(cond, skip);
   return Qnil;
@@ -460,8 +460,7 @@ static VALUE cond_set_options(VALUE vself, VALUE voptions){
   ESTCOND *cond;
   vcond = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(voptions, T_FIXNUM);
-  est_cond_set_options(cond, FIX2INT(voptions));
+  est_cond_set_options(cond, NUM2INT(voptions));
   return Qnil;
 }
 
@@ -471,8 +470,7 @@ static VALUE cond_set_auxiliary(VALUE vself, VALUE vmin){
   ESTCOND *cond;
   vcond = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(vmin, T_FIXNUM);
-  est_cond_set_auxiliary(cond, FIX2INT(vmin));
+  est_cond_set_auxiliary(cond, NUM2INT(vmin));
   return Qnil;
 }
 
@@ -492,8 +490,7 @@ static VALUE cond_set_mask(VALUE vself, VALUE vmask){
   ESTCOND *cond;
   vcond = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(vmask, T_FIXNUM);
-  est_cond_set_mask(cond, FIX2INT(vmask));
+  est_cond_set_mask(cond, NUM2INT(vmask));
   return Qnil;
 }
 
@@ -546,7 +543,7 @@ static VALUE res_doc_num(VALUE vself){
   ESTRES *res;
   vres = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vres, ESTRES, res);
-  return INT2FIX(res->num);
+  return INT2NUM(res->num);
 }
 
 
@@ -556,10 +553,9 @@ static VALUE res_get_doc_id(VALUE vself, VALUE vindex){
   int index;
   vres = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vres, ESTRES, res);
-  Check_Type(vindex, T_FIXNUM);
-  index = FIX2INT(vindex);
+  index = NUM2INT(vindex);
   if(!res->ids || index < 0 || index >= res->num) return -1;
-  return INT2FIX(res->ids[index]);
+  return INT2NUM(res->ids[index]);
 }
 
 
@@ -569,10 +565,9 @@ static VALUE res_get_dbidx(VALUE vself, VALUE vindex){
   int index;
   vres = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vres, ESTRES, res);
-  Check_Type(vindex, T_FIXNUM);
-  index = FIX2INT(vindex);
+  index = NUM2INT(vindex);
   if(!res->dbidxs || index < 0 || index >= res->num) return -1;
-  return INT2FIX(res->dbidxs[index]);
+  return INT2NUM(res->dbidxs[index]);
 }
 
 
@@ -606,9 +601,9 @@ static VALUE res_hint(VALUE vself, VALUE vword){
   vres = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vres, ESTRES, res);
   Check_Type(vword, T_STRING);
-  if(!res->hints) return INT2FIX(0);
-  if(!(value = cbmapget(res->hints, StringValuePtr(vword), -1, NULL))) return INT2FIX(0);
-  return INT2FIX(atoi(value));
+  if(!res->hints) return INT2NUM(0);
+  if(!(value = cbmapget(res->hints, StringValuePtr(vword), -1, NULL))) return INT2NUM(0);
+  return INT2NUM(atoi(value));
 }
 
 
@@ -620,8 +615,7 @@ static VALUE res_get_score(VALUE vself, VALUE vindex){
   Data_Get_Struct(vres, ESTRES, res);
   vcond = rb_iv_get(vself, VNCOND);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(vindex, T_FIXNUM);
-  return INT2FIX(est_cond_score(cond, FIX2INT(vindex)));
+  return INT2NUM(est_cond_score(cond, NUM2INT(vindex)));
 }
 
 
@@ -635,11 +629,10 @@ static VALUE res_get_shadows(VALUE vself, VALUE vid){
   Data_Get_Struct(vres, ESTRES, res);
   vcond = rb_iv_get(vself, VNCOND);
   Data_Get_Struct(vcond, ESTCOND, cond);
-  Check_Type(vid, T_FIXNUM);
-  ary = est_cond_shadows(cond, FIX2INT(vid), &anum);
+  ary = est_cond_shadows(cond, NUM2INT(vid), &anum);
   vary = rb_ary_new2(anum);
   for(i = 0; i < anum; i++){
-    rb_ary_push(vary, INT2FIX(ary[i]));
+    rb_ary_push(vary, INT2NUM(ary[i]));
   }
   return vary;
 }
@@ -649,40 +642,40 @@ static void db_init(void){
   cls_db = rb_define_class_under(mod_estraier, "Database", rb_cObject);
   cls_db_data = rb_define_class_under(mod_estraier, "Database_data", rb_cObject);
   rb_define_const(cls_db, "VERSION", rb_str_new2(est_version));
-  rb_define_const(cls_db, "ERRNOERR", INT2FIX(ESTENOERR));
-  rb_define_const(cls_db, "ERRINVAL", INT2FIX(ESTEINVAL));
-  rb_define_const(cls_db, "ERRACCES", INT2FIX(ESTEACCES));
-  rb_define_const(cls_db, "ERRLOCK", INT2FIX(ESTELOCK));
-  rb_define_const(cls_db, "ERRDB", INT2FIX(ESTEDB));
-  rb_define_const(cls_db, "ERRIO", INT2FIX(ESTEIO));
-  rb_define_const(cls_db, "ERRNOITEM", INT2FIX(ESTENOITEM));
-  rb_define_const(cls_db, "ERRMISC", INT2FIX(ESTEMISC));
-  rb_define_const(cls_db, "DBREADER", INT2FIX(ESTDBREADER));
-  rb_define_const(cls_db, "DBWRITER", INT2FIX(ESTDBWRITER));
-  rb_define_const(cls_db, "DBCREAT", INT2FIX(ESTDBCREAT));
-  rb_define_const(cls_db, "DBTRUNC", INT2FIX(ESTDBTRUNC));
-  rb_define_const(cls_db, "DBNOLCK", INT2FIX(ESTDBNOLCK));
-  rb_define_const(cls_db, "DBLCKNB", INT2FIX(ESTDBLCKNB));
-  rb_define_const(cls_db, "DBPERFNG", INT2FIX(ESTDBPERFNG));
-  rb_define_const(cls_db, "DBCHRCAT", INT2FIX(ESTDBCHRCAT));
-  rb_define_const(cls_db, "DBSMALL", INT2FIX(ESTDBSMALL));
-  rb_define_const(cls_db, "DBLARGE", INT2FIX(ESTDBLARGE));
-  rb_define_const(cls_db, "DBHUGE", INT2FIX(ESTDBHUGE));
-  rb_define_const(cls_db, "DBSCVOID", INT2FIX(ESTDBSCVOID));
-  rb_define_const(cls_db, "DBSCINT", INT2FIX(ESTDBSCINT));
-  rb_define_const(cls_db, "DBSCASIS", INT2FIX(ESTDBSCASIS));
-  rb_define_const(cls_db, "IDXATTRSEQ", INT2FIX(ESTIDXATTRSEQ));
-  rb_define_const(cls_db, "IDXATTRSTR", INT2FIX(ESTIDXATTRSTR));
-  rb_define_const(cls_db, "IDXATTRNUM", INT2FIX(ESTIDXATTRNUM));
-  rb_define_const(cls_db, "OPTNOPURGE", INT2FIX(ESTOPTNOPURGE));
-  rb_define_const(cls_db, "OPTNODBOPT", INT2FIX(ESTOPTNODBOPT));
-  rb_define_const(cls_db, "MGCLEAN", INT2FIX(ESTMGCLEAN));
-  rb_define_const(cls_db, "PDCLEAN", INT2FIX(ESTPDCLEAN));
-  rb_define_const(cls_db, "PDWEIGHT", INT2FIX(ESTPDWEIGHT));
-  rb_define_const(cls_db, "ODCLEAN", INT2FIX(ESTODCLEAN));
-  rb_define_const(cls_db, "GDNOATTR", INT2FIX(ESTGDNOATTR));
-  rb_define_const(cls_db, "GDNOTEXT", INT2FIX(ESTGDNOTEXT));
-  rb_define_const(cls_db, "GDNOKWD", INT2FIX(ESTGDNOKWD));
+  rb_define_const(cls_db, "ERRNOERR", INT2NUM(ESTENOERR));
+  rb_define_const(cls_db, "ERRINVAL", INT2NUM(ESTEINVAL));
+  rb_define_const(cls_db, "ERRACCES", INT2NUM(ESTEACCES));
+  rb_define_const(cls_db, "ERRLOCK", INT2NUM(ESTELOCK));
+  rb_define_const(cls_db, "ERRDB", INT2NUM(ESTEDB));
+  rb_define_const(cls_db, "ERRIO", INT2NUM(ESTEIO));
+  rb_define_const(cls_db, "ERRNOITEM", INT2NUM(ESTENOITEM));
+  rb_define_const(cls_db, "ERRMISC", INT2NUM(ESTEMISC));
+  rb_define_const(cls_db, "DBREADER", INT2NUM(ESTDBREADER));
+  rb_define_const(cls_db, "DBWRITER", INT2NUM(ESTDBWRITER));
+  rb_define_const(cls_db, "DBCREAT", INT2NUM(ESTDBCREAT));
+  rb_define_const(cls_db, "DBTRUNC", INT2NUM(ESTDBTRUNC));
+  rb_define_const(cls_db, "DBNOLCK", INT2NUM(ESTDBNOLCK));
+  rb_define_const(cls_db, "DBLCKNB", INT2NUM(ESTDBLCKNB));
+  rb_define_const(cls_db, "DBPERFNG", INT2NUM(ESTDBPERFNG));
+  rb_define_const(cls_db, "DBCHRCAT", INT2NUM(ESTDBCHRCAT));
+  rb_define_const(cls_db, "DBSMALL", INT2NUM(ESTDBSMALL));
+  rb_define_const(cls_db, "DBLARGE", INT2NUM(ESTDBLARGE));
+  rb_define_const(cls_db, "DBHUGE", INT2NUM(ESTDBHUGE));
+  rb_define_const(cls_db, "DBSCVOID", INT2NUM(ESTDBSCVOID));
+  rb_define_const(cls_db, "DBSCINT", INT2NUM(ESTDBSCINT));
+  rb_define_const(cls_db, "DBSCASIS", INT2NUM(ESTDBSCASIS));
+  rb_define_const(cls_db, "IDXATTRSEQ", INT2NUM(ESTIDXATTRSEQ));
+  rb_define_const(cls_db, "IDXATTRSTR", INT2NUM(ESTIDXATTRSTR));
+  rb_define_const(cls_db, "IDXATTRNUM", INT2NUM(ESTIDXATTRNUM));
+  rb_define_const(cls_db, "OPTNOPURGE", INT2NUM(ESTOPTNOPURGE));
+  rb_define_const(cls_db, "OPTNODBOPT", INT2NUM(ESTOPTNODBOPT));
+  rb_define_const(cls_db, "MGCLEAN", INT2NUM(ESTMGCLEAN));
+  rb_define_const(cls_db, "PDCLEAN", INT2NUM(ESTPDCLEAN));
+  rb_define_const(cls_db, "PDWEIGHT", INT2NUM(ESTPDWEIGHT));
+  rb_define_const(cls_db, "ODCLEAN", INT2NUM(ESTODCLEAN));
+  rb_define_const(cls_db, "GDNOATTR", INT2NUM(ESTGDNOATTR));
+  rb_define_const(cls_db, "GDNOTEXT", INT2NUM(ESTGDNOTEXT));
+  rb_define_const(cls_db, "GDNOKWD", INT2NUM(ESTGDNOKWD));
   rb_define_private_method(cls_db, "initialize", db_initialize, 0);
   rb_define_singleton_method(cls_db, "search_meta", db_search_meta, 2);
   rb_define_method(cls_db, "err_msg", db_err_msg, 1);
@@ -708,6 +701,7 @@ static void db_init(void){
   rb_define_method(cls_db, "search", db_search, 1);
   rb_define_method(cls_db, "scan_doc", db_scan_doc, 2);
   rb_define_method(cls_db, "set_cache_size", db_set_cache_size, 4);
+  rb_define_method(cls_db, "add_pseudo_index", db_add_pseudo_index, 1);
   rb_define_method(cls_db, "set_wildmax", db_set_wildmax, 1);
   rb_define_method(cls_db, "set_informer", db_set_informer, 1);
 }
@@ -789,8 +783,7 @@ static VALUE db_search_meta(VALUE vself, VALUE vdbs, VALUE vcond){
 
 
 static VALUE db_err_msg(VALUE vself, VALUE vecode){
-  Check_Type(vecode, T_FIXNUM);
-  return rb_str_new2(est_err_msg(FIX2INT(vecode)));
+  return rb_str_new2(est_err_msg(NUM2INT(vecode)));
 }
 
 
@@ -804,8 +797,7 @@ static VALUE db_open(VALUE vself, VALUE vname, VALUE vomode){
     return Qfalse;
   }
   Check_Type(vname, T_STRING);
-  Check_Type(vomode, T_FIXNUM);
-  if(!(db->db = est_mtdb_open(StringValuePtr(vname), FIX2INT(vomode), &(db->ecode))))
+  if(!(db->db = est_mtdb_open(StringValuePtr(vname), NUM2INT(vomode), &(db->ecode))))
     return Qfalse;
   return Qtrue;
 }
@@ -831,7 +823,7 @@ static VALUE db_error(VALUE vself){
   ESTDBMGR *db;
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
-  return INT2FIX(db->ecode);
+  return INT2NUM(db->ecode);
 }
 
 
@@ -852,8 +844,7 @@ static VALUE db_add_attr_index(VALUE vself, VALUE vname, VALUE vtype){
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) return Qfalse;
   Check_Type(vname, T_STRING);
-  Check_Type(vtype, T_FIXNUM);
-  if(!est_mtdb_add_attr_index(db->db, StringValuePtr(vname), FIX2INT(vtype))){
+  if(!est_mtdb_add_attr_index(db->db, StringValuePtr(vname), NUM2INT(vtype))){
     db->ecode = est_mtdb_error(db->db);
     return Qfalse;
   }
@@ -867,8 +858,7 @@ static VALUE db_flush(VALUE vself, VALUE vmax){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(vmax, T_FIXNUM);
-  if(!est_mtdb_flush(db->db, FIX2INT(vmax))){
+  if(!est_mtdb_flush(db->db, NUM2INT(vmax))){
     db->ecode = est_mtdb_error(db->db);
     return Qfalse;
   }
@@ -896,8 +886,7 @@ static VALUE db_optimize(VALUE vself, VALUE voptions){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(voptions, T_FIXNUM);
-  if(!est_mtdb_optimize(db->db, FIX2INT(voptions))){
+  if(!est_mtdb_optimize(db->db, NUM2INT(voptions))){
     db->ecode = est_mtdb_error(db->db);
     return Qfalse;
   }
@@ -912,8 +901,7 @@ static VALUE db_merge(VALUE vself, VALUE vname, VALUE voptions){
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
   Check_Type(vname, T_STRING);
-  Check_Type(voptions, T_FIXNUM);
-  if(!est_mtdb_merge(db->db, StringValuePtr(vname), FIX2INT(voptions))){
+  if(!est_mtdb_merge(db->db, StringValuePtr(vname), NUM2INT(voptions))){
     db->ecode = est_mtdb_error(db->db);
     return Qfalse;
   }
@@ -929,9 +917,8 @@ static VALUE db_put_doc(VALUE vself, VALUE vdoc, VALUE voptions){
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
   if(rb_obj_is_instance_of(vdoc, cls_doc) != Qtrue) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(voptions, T_FIXNUM);
   Data_Get_Struct(rb_iv_get(vdoc, VNDATA), ESTDOC, doc);
-  if(!est_mtdb_put_doc(db->db, doc, FIX2INT(voptions))){
+  if(!est_mtdb_put_doc(db->db, doc, NUM2INT(voptions))){
     db->ecode = est_mtdb_error(db->db);
     return Qfalse;
   }
@@ -946,11 +933,9 @@ static VALUE db_out_doc(VALUE vself, VALUE vid, VALUE voptions){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(vid, T_FIXNUM);
-  Check_Type(voptions, T_FIXNUM);
-  id = FIX2INT(vid);
+  id = NUM2INT(vid);
   if(id < 1) rb_raise(rb_eArgError, "invalid argument");
-  if(!est_mtdb_out_doc(db->db, id, FIX2INT(voptions))){
+  if(!est_mtdb_out_doc(db->db, id, NUM2INT(voptions))){
     db->ecode = est_mtdb_error(db->db);
     return Qfalse;
   }
@@ -983,11 +968,9 @@ static VALUE db_get_doc(VALUE vself, VALUE vid, VALUE voptions){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(vid, T_FIXNUM);
-  Check_Type(voptions, T_FIXNUM);
-  id = FIX2INT(vid);
+  id = NUM2INT(vid);
   if(id < 1) rb_raise(rb_eArgError, "invalid argument");
-  if(!(doc = est_mtdb_get_doc(db->db, id, FIX2INT(voptions)))){
+  if(!(doc = est_mtdb_get_doc(db->db, id, NUM2INT(voptions)))){
     db->ecode = est_mtdb_error(db->db);
     return Qnil;
   }
@@ -1006,9 +989,8 @@ static VALUE db_get_doc_attr(VALUE vself, VALUE vid, VALUE vname){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(vid, T_FIXNUM);
   Check_Type(vname, T_STRING);
-  id = FIX2INT(vid);
+  id = NUM2INT(vid);
   if(id < 1) rb_raise(rb_eArgError, "invalid argument");
   if(!(value = est_mtdb_get_doc_attr(db->db, id, StringValuePtr(vname)))){
     db->ecode = est_mtdb_error(db->db);
@@ -1030,9 +1012,9 @@ static VALUE db_uri_to_id(VALUE vself, VALUE vuri){
   Check_Type(vuri, T_STRING);
   if((id = est_mtdb_uri_to_id(db->db, StringValuePtr(vuri))) == -1){
     db->ecode = est_mtdb_error(db->db);
-    return INT2FIX(-1);
+    return INT2NUM(-1);
   }
-  return INT2FIX(id);
+  return INT2NUM(id);
 }
 
 
@@ -1052,7 +1034,7 @@ static VALUE db_doc_num(VALUE vself){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  return INT2FIX(est_mtdb_doc_num(db->db));
+  return INT2NUM(est_mtdb_doc_num(db->db));
 }
 
 
@@ -1062,7 +1044,7 @@ static VALUE db_word_num(VALUE vself){
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  return INT2FIX(est_mtdb_word_num(db->db));
+  return INT2NUM(est_mtdb_word_num(db->db));
 }
 
 
@@ -1125,23 +1107,30 @@ static VALUE db_set_cache_size(VALUE vself, VALUE vsize, VALUE vanum, VALUE vtnu
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(vanum, T_FIXNUM);
-  Check_Type(vtnum, T_FIXNUM);
-  Check_Type(vrnum, T_FIXNUM);
   est_mtdb_set_cache_size(db->db, NUM2INT(vsize),
-                          FIX2INT(vanum), FIX2INT(vtnum), FIX2INT(vrnum));
+                          NUM2INT(vanum), NUM2INT(vtnum), NUM2INT(vrnum));
   return Qnil;
 }
 
 
+static VALUE db_add_pseudo_index(VALUE vself, VALUE vpath){
+  VALUE vdb;
+  ESTDBMGR *db;
+  vdb = rb_iv_get(vself, VNDATA);
+  Data_Get_Struct(vdb, ESTDBMGR, db);
+  if(!db->db) rb_raise(rb_eArgError, "invalid argument");
+  Check_Type(vpath, T_STRING);
+  return est_mtdb_add_pseudo_index(db->db, StringValuePtr(vpath)) ? Qtrue : Qfalse;
+}
+
+
 static VALUE db_set_wildmax(VALUE vself, VALUE vnum){
   VALUE vdb;
   ESTDBMGR *db;
   vdb = rb_iv_get(vself, VNDATA);
   Data_Get_Struct(vdb, ESTDBMGR, db);
   if(!db->db) rb_raise(rb_eArgError, "invalid argument");
-  Check_Type(vnum, T_FIXNUM);
-  est_mtdb_set_wildmax(db->db, FIX2INT(vnum));
+  est_mtdb_set_wildmax(db->db, NUM2INT(vnum));
   return Qnil;
 }
 
