@@ -96,9 +96,9 @@ def usage()
   STDERR.printf("  %s inform [-proxy host port] [-tout num] [-auth user pass] nurl\n", $0)
   STDERR.printf("  %s sync [-proxy host port] [-tout num] [-auth user pass] nurl\n", $0)
   STDERR.printf("  %s optimize [-proxy host port] [-tout num] [-auth user pass] nurl\n", $0)
-  STDERR.printf("  %s search [-proxy host port] [-tout num] [-auth user pass] [-kw] [-sf]" \
-                " [-attr expr] [-ord expr] [-max num] [-sk num] [-dpt num] [-mask num]" \
-                " nurl [phrase]\n", $0)
+  STDERR.printf("  %s search [-proxy host port] [-tout num] [-auth user pass]" \
+                " [-sf|-sfr|-sfu|-sfi] [-attr expr] [-ord expr] [-max num] [-sk num]" \
+                " [-dpt num] [-mask num] nurl [phrase]\n", $0)
   STDERR.printf("  %s setuser [-proxy host port] [-tout num] [-auth user pass]" \
                 " nurl name mode\n", $0)
   STDERR.printf("  %s setlink [-proxy host port] [-tout num] [-auth user pass]" \
@@ -475,10 +475,14 @@ def runsearch(args)
         $authname = args[i]
         usage if (i += 1) >= args.length
         $authpass = args[i]
-      elsif args[i] == "-kw"
-        opts |= Condition::ETCH
       elsif args[i] == "-sf"
         opts |= Condition::SIMPLE
+      elsif args[i] == "-sfr"
+        opts |= Condition::ROUGH
+      elsif args[i] == "-sfu"
+        opts |= Condition::UNION
+      elsif args[i] == "-sfi"
+        opts |= Condition::ISECT
       elsif args[i] == "-attr"
         usage if (i += 1) >= args.length
         attrs.push(args[i])
