@@ -224,6 +224,12 @@ module EstraierPure
     NOIDF = 1 << 4
     # option: with the simplified phrase
     SIMPLE = 1 << 10
+    # option: with the rough phrase
+    ROUGH = 1 << 11
+    # option: with the union phrase
+    UNION = 1 << 15
+    # option: with the intersection phrase
+    ISECT = 1 << 16
     #--------------------------------
     # public methods
     #--------------------------------
@@ -280,9 +286,10 @@ module EstraierPure
     # key, `Condition::USU', which is the default, specifies that it checks N-gram keys
     # with skipping one key, `Condition::FAST' skips two keys, `Condition::AGITO'
     # skips three keys, `Condition::NOIDF' specifies not to perform TF-IDF tuning,
-    # `Condition::SIMPLE' specifies to use simplified phrase.  Each option can be specified at
-    # the same time by bitwise or.  If keys are skipped, though search speed is improved, the
-    # relevance ratio grows less.
+    # `Condition::SIMPLE' specifies to use simplified phrase, `Condition::ROUGH' specifies to use
+    # rough phrase, `Condition.UNION' specifies to use union phrase, `Condition.ISECT' specifies
+    # to use intersection phrase.  Each option can be specified at the same time by bitwise or.
+    # If keys are skipped, though search speed is improved, the relevance ratio grows less.
     # The return value is always `nil'.
     def set_options(options)
       Utility::check_types({ options=>Integer }) if $DEBUG
