@@ -118,7 +118,7 @@ int log_rotate(const char *rootdir, const char *path){
   char mypath[URIBUFSIZ], *wp, iobuf[IOBUFSIZ];
   int err, year, month, day, hour, minute, second, len;
   assert(rootdir && path);
-  if(!log_fp || fflush(log_fp) == -1) return FALSE;;
+  if(!log_fp || fflush(log_fp) == -1) return FALSE;
   err = FALSE;
   wp = mypath;
   if((ESTPATHCHR == '/' && path[0] == ESTPATHCHR) ||
@@ -143,7 +143,7 @@ int log_rotate(const char *rootdir, const char *path){
   if(fclose(ifp) == -1) err = TRUE;
   if(fseek(log_fp, 0, SEEK_SET) == -1 || fflush(log_fp) == -1) err = TRUE;
   if(ftruncate(fileno(log_fp), 0) == -1) err = TRUE;
-  return err ? FALSE : TRUE;;
+  return err ? FALSE : TRUE;
 }
 
 
@@ -205,6 +205,9 @@ int waver_init(const char *rootdir){
     fprintf(ofp, "# maximum number of records of the priority queue\n");
     fprintf(ofp, "queuesize: 50000\n");
     fprintf(ofp, "\n");
+    fprintf(ofp, "# regular expressions and replacement strings to normalize URLs\n");
+    fprintf(ofp, "replace: ^http://127.0.0.1/{{!}}http://localhost/\n");
+    fprintf(ofp, "\n");
     fprintf(ofp, "# allowing regular expressions of URLs to be visited.\n");
     fprintf(ofp, "allowrx: ^http://\n");
     fprintf(ofp, "\n");
@@ -216,7 +219,7 @@ int waver_init(const char *rootdir){
     fprintf(ofp, "denyrx: \\.(zip|tar|tgz|gz|bz2|tbz2|z|lha|lzh)(\\?.*)?$\n");
     fprintf(ofp, "denyrx: \\.(7z|lzo|lzma|cpio|shar|cab|rar|sit|ace|hqx)(\\?.*)?$\n");
     fprintf(ofp, "denyrx: \\.(bin|o|a|so|exe|dll|lib|obj|ocx|class|jar|war)(\\?.*)?$\n");
-    fprintf(ofp, "denyrx: \\.(rpm|deb|qdb|qdb|dbx|dbf|dat|msi|bat|com)(\\?.*)?$\n");
+    fprintf(ofp, "denyrx: \\.(rpm|deb|qdb|qdb|dbx|dbf|dat|msi|bat|com|iso)(\\?.*)?$\n");
     fprintf(ofp, "denyrx: \\.(png|gif|jpg|jpeg|tif|tiff|bmp|ico|pbm|pgm|ppm|xbm|xpm|dvi)$\n");
     fprintf(ofp, "denyrx: \\.(au|snd|mid|midi|kar|smf|mp2|mp3|m3u|wav|wma|wmp|asx|at3|aif)$\n");
     fprintf(ofp, "denyrx: \\.(mpg|mpeg|qt|mov|avi|wmv|wvx|asf|ram|rm)$\n");
@@ -321,6 +324,7 @@ int waver_init(const char *rootdir){
 /* Open a waver handle. */
 WAVER *waver_open(const char *rootdir){
   WAVER *waver;
+  UNRULE unrule;
   PMRULE pmrule;
   MTRULE mtrule;
   DEPOT *metadb;
@@ -372,6 +376,7 @@ WAVER *waver_open(const char *rootdir){
   waver->maxdepth = INT_MAX;
   waver->masscheck = INT_MAX;
   waver->queuesize = INT_MAX;
+  waver->unrules = cblistopen();
   waver->pmrules = cblistopen();
   waver->mtrules = cblistopen();
   waver->language = ESTLANGEN;
@@ -424,6 +429,18 @@ WAVER *waver_open(const char *rootdir){
       waver->masscheck = atoi(skiplabel(rp));
     } else if(cbstrfwimatch(rp, "queuesize:")){
       waver->queuesize = atoi(skiplabel(rp));
+    } else if(cbstrfwimatch(rp, "replace:")){
+      rp = skiplabel(rp);
+      if((pv = strstr(rp, "{{!}}")) != NULL){
+        tmp = cbmemdup(rp, pv - rp);
+        if((unrule.regex = est_regex_new(tmp)) != NULL){
+          unrule.before = tmp;
+          unrule.after = cbmemdup(pv + 5, -1);
+          cblistpush(waver->unrules, (char *)&unrule, sizeof(UNRULE));
+        } else {
+          free(tmp);
+        }
+      }
     } else if(cbstrfwimatch(rp, "allowrx:")){
       tmp = cbsprintf("*I:%s", skiplabel(rp));
       if((pmrule.regex = est_regex_new(tmp)) != NULL){
@@ -544,6 +561,7 @@ WAVER *waver_open(const char *rootdir){
 
 /* Close a waver handle. */
 int waver_close(WAVER *waver){
+  UNRULE *unrule;
   PMRULE *pmrule;
   MTRULE *mtrule;
   ESTNODE *node;
@@ -571,6 +589,13 @@ int waver_close(WAVER *waver){
     est_regex_delete(pmrule->regex);
   }
   cblistclose(waver->pmrules);
+  for(i = 0; i < cblistnum(waver->unrules); i++){
+    unrule = (UNRULE *)cblistval(waver->unrules, i, NULL);
+    est_regex_delete(unrule->regex);
+    free(unrule->before);
+    free(unrule->after);
+  }
+  cblistclose(waver->unrules);
   free(waver->pxhost);
   cbmapclose(waver->sites);
   cbmapclose(waver->kwords);
@@ -806,15 +831,16 @@ void kwords_reduce(CBMAP *kwords, int num, int fadeout){
 /* Fetch a document of a URL. */
 int fetch_document(const char *url, const char *pxhost, int pxport, int outsec, time_t mdate,
                    const CBLIST *mtrules, int *codep, CBDATUM *raw, CBMAP *heads,
-                   CBLIST *links, ESTDOC *doc, int lang){
+                   CBLIST *links, const CBLIST *unrules, ESTDOC *doc, int lang){
   MTRULE *mtrule;
+  UNRULE *unrule;
   ESTDOC *rdoc;
   CBMAP *rheads;
   CBLIST *reqheads;
   CBDATUM *rbuf;
   const char *vbuf, *cmd;
   char *dstr, *tbuf, *type, *enc, *pv;
-  int i, rescode;
+  int i, j, rescode;
   assert(url);
   rescode = -1;
   if(raw){
@@ -922,6 +948,15 @@ int fetch_document(const char *url, const char *pxhost, int pxport, int outsec,
   if(links){
     for(i = 0; i < cblistnum(links); i++){
       tbuf = cburlresolve(url, cblistval(links, i, NULL));
+      if(unrules){
+        for(j = 0; j < cblistnum(unrules); j++){
+          unrule = (UNRULE *)cblistval(unrules, j, NULL);
+          if(!est_regex_match(unrule->regex, tbuf)) continue;
+          dstr = est_regex_replace(tbuf, unrule->before, unrule->after);
+          free(tbuf);
+          tbuf = dstr;
+        }
+      }
       if(cbstrfwmatch(tbuf, "http://")){
         pv = tbuf + 7;
         if((pv = strchr(pv, '/')) != NULL && cbstrfwmatch(pv, "/%E2%80%BE")){
